@@ -33,6 +33,15 @@ def set(version):
         print("Must set version on release branch")
 
 
+# commit
+@release.command()
+def add_commit():
+
+    git.add()
+
+    git.commit()
+
+
 # submit version
 @release.command()
 @click.argument("version")
@@ -43,3 +52,19 @@ def submit(version):
         git.release_request(version)
     else:
         print("Must set version on release branch")
+
+
+# finish
+@release.command()
+def finish():
+    branch = git.current_branch()
+
+    git.change_to_branch("main")
+
+    git.pull("origin", "main")
+
+    git.change_to_branch("develop")
+
+    git.merge("main")
+
+    git.delete(branch)
